
# Slot: value


the actual annotation

URI: [linkml:extension_value](https://w3id.org/linkml/extension_value)


## Domain and Range

[Extension](Extension.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Annotation](Annotation.md)
 * [Extension](Extension.md)
